@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::BumpVersionAfterRelease;
 # ABSTRACT: Bump module versions after distribution release
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Moose;
 with(
@@ -191,7 +191,7 @@ Dist::Zilla::Plugin::BumpVersionAfterRelease - Bump module versions after distri
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -433,18 +433,26 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Kent Fredric
+=for stopwords David Golden Karen Etheridge Kent Fredric Klaus Eichner
 
 =over 4
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
 Kent Fredric <kentfredric@gmail.com>
 
+=item *
+
+Klaus Eichner <klaus03@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
